==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/interceptors/tests/contract/invocationContext/PostConstructInterceptor.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.interceptors.tests.contract.invocationContext;

import javax.annotation.PostConstruct;
import javax.interceptor.InvocationContext;

public class PostConstructInterceptor {
    private static boolean getMethodReturnsNull = false;
    private static boolean ctxProceedReturnsNull = false;

    @PostConstruct
    public void postConstruct(InvocationContext ctx) {
        getMethodReturnsNull = ctx.getMethod() == null;
        try {
            ctxProceedReturnsNull = ctx.proceed() == null;
        } catch (Exception e) {
        }
    }

    public static boolean isGetMethodReturnsNull() {
        return getMethodReturnsNull;
    }

    public static boolean isCtxProceedReturnsNull() {
        return ctxProceedReturnsNull;
    }
}

==> cdi-tck-3.0.2-dist.zip: org/jboss/cdi/tck/interceptors/tests/contract/invocationContext/PostConstructInterceptor.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.interceptors.tests.contract.invocationContext;

import jakarta.annotation.PostConstruct;
import jakarta.interceptor.InvocationContext;

public class PostConstructInterceptor {
    private static boolean getMethodReturnsNull = false;
    private static boolean ctxProceedReturnsNull = false;

    @PostConstruct
    public void postConstruct(InvocationContext ctx) {
        getMethodReturnsNull = ctx.getMethod() == null;
        try {
            ctxProceedReturnsNull = ctx.proceed() == null;
        } catch (Exception e) {
        }
    }

    public static boolean isGetMethodReturnsNull() {
        return getMethodReturnsNull;
    }

    public static boolean isCtxProceedReturnsNull() {
        return ctxProceedReturnsNull;
    }
}
